@@ -16,14 +16,13 @@ def vault(screen, child_obj):
 
     input = Input(screen, 2, 2, 30, "Login: ")
     select = Select(screen, 2, 2, "Profession: ", ["Student", "Teacher", "News"])
-    counter = Counter(screen, 2, 2, 0, 100, "Age: ")
-    form = Form(screen, 4, 2, "Login", {'login': input, 'profession': select, 'age': counter })
+    file = File(screen, 2, 2, "File: ")
+    form = Form(screen, 4, 2, "Login", {'login': input, 'profession': select, 'file': file })
 
     return [[(form, home)]]
 
-def main():
-    screen = Screen()
-
+def main(screen):
+    curses.curs_set(0)
     screen.box()
 
     elements = home(screen)
@@ -39,7 +38,5 @@ def main():
         if(res in ['ALT_Q']): break
         else: elements = res[1](screen, res[0])
         screen.box()
-    
-    screen.close()
 
-main()
\ No newline at end of file
+Screen(main)
\ No newline at end of file
